# ![fugo](https://raw.githubusercontent.com/ujan-r/fugo/main/assets/logo.png)

[![PyPI](https://img.shields.io/pypi/v/fugo)](https://pypi.org/project/fugo/)
[![license: MIT](https://img.shields.io/github/license/ujan-r/fugo)](https://github.com/ujan-r/fugo/blob/main/LICENSE)
[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![tests](https://github.com/ujan-r/fugo/actions/workflows/test.yml/badge.svg)](https://github.com/ujan-r/fugo/actions/workflows/test.yml)

**Fugo** ("_fugue-oh_") is a simple Python package for manipulating melodies and
writing counterpoint.
